# Basic Tutorials

AutoRA consists of modules specific to different stages of empirical research as well as supporting utilities and ancillary research procedures. The following tutorials demonstrate how to use these various components, and how to integrate them into closed-loop scientific discovery.

Once you understand the basics of AutoRA, you may be curious how to apply AutoRA to real-world discovery problems. You can find use case examples of AutoRA in the [Use Case Tutorials](../examples/index.md) section. 

If you have questions about these tutorials or would otherwise like to discuss use of AutoRA, feel free to start or join a discussion in the [Using AutoRA](https://github.com/orgs/AutoResearch/discussions/categories/using-autora) section of the AutoRA forum.
